@@ -79,7 +79,8 @@ class FFDirector(SectionLineParser):
         'dihedral_restraints': 4,
         'orientation_restraints': 2,
         'angle_restraints': 4,
-        'angle_restraints_z': 2
+        'angle_restraints_z': 2,
+        'cmap': 5,
     }
 
     def __init__(self, force_field):
@@ -222,6 +223,44 @@ class FFDirector(SectionLineParser):
     def _block_atoms(self, line, lineno=0):
         tokens = collections.deque(_tokenize(line))
         _parse_block_atom(tokens, self.current_block)
+        
+    @SectionLineParser.section_parser('moleculetype', 'meta')
+    def _parse_block_meta(self, line, lineno=0):
+        """
+        Parse the meta section and update the object current_block with meta information. 
+        Allow the dictionnary value to be None (in case of flag), string, int or float. 
+        
+        Example :
+            [meta]
+            flag1
+            key value
+            key2 value1 0.37 
+        
+            will give :
+                {   
+                    'flag1' : None, 
+                    'key': 'value', 
+                    'key2': ['value1' , '0.37']
+                }
+        
+        Parameters
+        ----------
+        line: str
+        lineno: str
+        """
+        
+        split_line = line.split()
+        key = split_line[0]
+        
+        # depend of the number of value(s) 
+        if len(split_line[1:]) == 0 : 
+            value = None
+        elif len(split_line[1:]) == 1 : 
+            value = split_line[1]
+        else: 
+            value = split_line[1:]
+        
+        self.current_block.meta[key] = value
 
     @SectionLineParser.section_parser('moleculetype', 'edges',
                                       negate=False, context_type='block')
@@ -256,10 +295,10 @@ class FFDirector(SectionLineParser):
     @SectionLineParser.section_parser('moleculetype', 'orientation_restraints', context_type='block')
     @SectionLineParser.section_parser('moleculetype', 'angle_restraints', context_type='block')
     @SectionLineParser.section_parser('moleculetype', 'angle_restraints_z', context_type='block')
+    @SectionLineParser.section_parser('moleculetype', 'cmap', context_type='block')
     @SectionLineParser.section_parser('link', 'bonds', context_type='link')
     @SectionLineParser.section_parser('link', 'angles', context_type='link')
     @SectionLineParser.section_parser('link', 'impropers', context_type='link')
-
     @SectionLineParser.section_parser('link', 'constraints', context_type='link')
     @SectionLineParser.section_parser('link', 'pairs', context_type='link')
     @SectionLineParser.section_parser('link', 'exclusions', context_type='link')
@@ -275,6 +314,7 @@ class FFDirector(SectionLineParser):
     @SectionLineParser.section_parser('link', 'orientation_restraints', context_type='link')
     @SectionLineParser.section_parser('link', 'angle_restraints', context_type='link')
     @SectionLineParser.section_parser('link', 'angle_restraints_z', context_type='link')
+    @SectionLineParser.section_parser('link', 'cmap', context_type='link')
     @SectionLineParser.section_parser('link', '!bonds', context_type='link')
     @SectionLineParser.section_parser('link', '!angles', context_type='link')
     @SectionLineParser.section_parser('link', '!impropers', context_type='link')
@@ -293,6 +333,7 @@ class FFDirector(SectionLineParser):
     @SectionLineParser.section_parser('link', '!orientation_restraints', context_type='link')
     @SectionLineParser.section_parser('link', '!angle_restraints', context_type='link')
     @SectionLineParser.section_parser('link', '!angle_restraints_z', context_type='link')
+    @SectionLineParser.section_parser('link', '!cmap', context_type='link')
     @SectionLineParser.section_parser('modification', 'bonds', context_type='modification')
     @SectionLineParser.section_parser('modification', 'angles', context_type='modification')
     @SectionLineParser.section_parser('modification', 'impropers', context_type='modification')
@@ -311,6 +352,7 @@ class FFDirector(SectionLineParser):
     @SectionLineParser.section_parser('modification', 'orientation_restraints', context_type='modification')
     @SectionLineParser.section_parser('modification', 'angle_restraints', context_type='modification')
     @SectionLineParser.section_parser('modification', 'angle_restraints_z', context_type='modification')
+    @SectionLineParser.section_parser('modification', 'cmap', context_type='modification')
     def _interactions(self, line, lineno=0, context_type=''):
         context = self.get_context(context_type)
         interaction_name = self.section[-1]
