@@ -356,10 +356,12 @@ class Molecule(nx.Graph):
         self.nrexcl = kwargs.pop('nrexcl', None)
         super().__init__(*args, **kwargs)
         self.interactions = defaultdict(list)
-        self.citations = set()
+        self.citations = {'vermouth'}  # This is part of martinize2/vermouth, so you should cite it!
         # {loglevel: {entry: [fmt_args]}}
         self.log_entries = defaultdict(lambda: defaultdict(list))
         self.max_node = None
+        # box of the system the molecule is in
+        self.box = None
 
     def __eq__(self, other):
         return (
@@ -430,6 +432,10 @@ class Molecule(nx.Graph):
             node_attr = self.nodes[node]
             yield node, node_attr
 
+    @property
+    def sorted_nodes(self):
+        yield from sorted(self.nodes, key=lambda n_idx: self.nodes[n_idx].get('atomid', np.inf))
+
     def copy(self):
         """
         Creates a copy of the molecule.
@@ -726,7 +732,8 @@ class Molecule(nx.Graph):
                 self.add_interaction(name, atoms, interaction.parameters, interaction.meta)
         for node1, node2 in molecule.edges:
             if correspondence[node1] != correspondence[node2]:
-                self.add_edge(correspondence[node1], correspondence[node2])
+                attrs = molecule.edges[(node1, node2)]
+                self.add_edge(correspondence[node1], correspondence[node2], **attrs)
         # merge the citation sets
         self.citations.update(molecule.citations)
         # Merge the log entries
@@ -1221,8 +1228,9 @@ class Block(Molecule):
                     interaction.parameters,
                     meta=interaction.meta
                 )
-        for edge in self.edges:
-            mol.add_edge(*(name_to_idx[node] for node in edge))
+        for nodea, nodeb, attrs in self.edges(data=True):
+            edge = (nodea, nodeb)
+            mol.add_edge(*(name_to_idx[node] for node in edge), **attrs)
 
         try:
             mol.nrexcl = self.nrexcl
@@ -1344,7 +1352,7 @@ def attributes_match(attributes, template_attributes, ignore_keys=()):
 
     Returns ``True`` if the attributes from the link match the ones from the
     molecule; returns ``False`` otherwise. The attributes from a link match
-    with those of a molecule is all the individual attribute from the link
+    with those of a molecule if all the individual attribute from the link
     match the corresponding ones in the molecule. In the simplest case, these
     attribute match if their values are equal. If the value of the link
     attribute is an instance of :class:`LinkPredicate`, then the attributes
