@@ -61,6 +61,7 @@ class PDBParser(LineParser):
         self.ignh = ignh
         self.modelidx = modelidx
         self._skipahead = False
+        self.cryst = {}
 
     def dispatch(self, line):
         """
@@ -151,7 +152,6 @@ class PDBParser(LineParser):
     site   = _skip
 
     # CRYSTALLOGRAPHIC AND COORDINATE TRANSFORMATION SECTION
-    cryst1 = _skip
     origx1 = _skip
     origx2 = _skip
     origx3 = _skip
@@ -265,6 +265,37 @@ class PDBParser(LineParser):
     atom = _atom
     hetatm = _atom
 
+    def cryst1(self, line, lineno=0):
+        """
+        Parse the CRYST1 record. Crystal structure information are stored with
+        the parser object and may be extracted later.
+        """
+        fields = [
+            ('', str, 6),
+            ('a', float, 9),
+            ('b', float, 9),
+            ('c', float, 9),
+            ('alpha', float, 7),
+            ('beta', float, 7),
+            ('gamma', float, 7),
+            ('space_group', str, 11),
+            ('', str, 1),
+            ('z_value', int, 4),
+            ]
+        start = 0
+        field_slices = []
+        for name, type_, width in fields:
+            if name:
+                field_slices.append((name, type_, slice(start, start + width)))
+            start += width
+
+        for name, type_, slice_ in field_slices:
+            value = line[slice_].strip()
+            if value:
+                self.cryst[name] = type_(value)
+            else:
+                LOGGER.warning(f"CRYST1 directive incomplete. Missing entry for {name}.")
+
     def model(self, line, lineno=0):
         """
         Parse a MODEL record. If the model is not the same as :attr:`modelidx`,
@@ -310,6 +341,10 @@ class PDBParser(LineParser):
         # since there's a very good chance it's CONECT records have not been
         # parsed yet, and the molecule won't have any edges.
         if self.active_molecule:
+            if {"a", "b", "c"}.issubset(set(self.cryst.keys())):
+                self.active_molecule.box = np.array([self.cryst['a']/10.,
+                                                     self.cryst['b']/10.,
+                                                     self.cryst['c']/10.])
             self.molecules.append(self.active_molecule)
         self.active_molecule = Molecule()
 
@@ -498,7 +533,7 @@ def write_pdb_string(system, conect=True, omit_charges=True, nan_missing_pos=Fal
     nodeidx2atomid = {}
     atomid = 1
     for mol_idx, molecule in enumerate(system.molecules):
-        for node_idx in molecule:
+        for node_idx in molecule.sorted_nodes:
             # Node indices do not have to be unique across molecules. So store
             # them as (mol_idx, node_idx)
             nodeidx2atomid[(mol_idx, node_idx)] = atomid
@@ -508,7 +543,7 @@ def write_pdb_string(system, conect=True, omit_charges=True, nan_missing_pos=Fal
             resname = get_not_none(node, 'resname', '')
             chain = get_not_none(node, 'chain', '')
             resid = get_not_none(node, 'resid', 1)
-            insertion_code = get_not_none(node, 'insertioncode', '')
+            insertion_code = get_not_none(node, 'insertion_code', '')
             try:
                 # converting from nm to A
                 x, y, z = node['position'] * 10  # pylint: disable=invalid-name
