@@ -89,11 +89,20 @@ def compute_force_constants(distance_matrix, lower_bound, upper_bound,
 
     The force constant can be modified with a decay function, and it can be
     bounded with a minimum threshold, or a distance upper and lower bonds.
+    
+    If decay_factor = decay_power = 0 all forces applied are = base_constant
+    
+    Forces applied to distances above upper_bound are removed.
+    Forces below minimum_force are removed.
+    
+    If decay_factor or decay_power != 0, forces below lower_bound are greater 
+    than base_constant, in which case they are set back to = base_constant    
     """
     constants = compute_decay(distance_matrix, lower_bound, decay_factor, decay_power)
     np.fill_diagonal(constants, 0)
     constants *= base_constant
     constants[constants < minimum_force] = 0
+    constants[constants > base_constant] = base_constant
     constants[distance_matrix > upper_bound] = 0
     return constants
 
@@ -382,12 +391,12 @@ def same_chain(graph, left, right):
 
 def make_same_region_criterion(regions):
     """
-    Returns ``True`` is the nodes are part of the same region.
+    Returns ``True`` if the nodes are part of the same region.
 
     Nodes are considered part of the same region if their value
     under the "resid" attribute are within the same residue range.
-    By default the resids of the input file are used (i.e. "_old_resid"
-    attribute).
+    By default the resids of the input file are used from the
+    stashed value
 
     Parameters
     ----------
@@ -411,8 +420,14 @@ def make_same_region_criterion(regions):
     def same_region(graph, left, right):
         node_left = graph.nodes[left]
         node_right = graph.nodes[right]
-        left_resid = node_left.get('_old_resid', node_left['resid'])
-        right_resid = node_right.get('_old_resid', node_right['resid'])
+        try:
+            left_resid = node_left['stash']['resid']
+        except KeyError:
+            left_resid = node_left['resid']
+        try:
+            right_resid = node_right['stash']['resid']
+        except KeyError:
+            right_resid = node_right['resid']
         for region in regions:
             lower = min(region)
             upper = max(region)
