@@ -477,7 +477,7 @@ def apply_mod_mapping(match, molecule, graph_out, mol_to_out, out_to_mol):
             assert len(atoms) == len(interaction.atoms)
             interaction = interaction._replace(atoms=atoms)
             applied_interactions[interaction_type][tuple(atoms)].append(modification)
-            graph_out.add_interaction(interaction_type, **interaction._asdict())
+            graph_out.add_or_replace_interaction(interaction_type, **interaction._asdict())
 
     # Some jank needed here, since modification node indices are integers
     mod_atom_name_to_out = {}
@@ -511,7 +511,7 @@ def attrs_from_node(node, attrs):
     return {attr: val for attr, val in node.items() if attr in attrs}
 
 
-def do_mapping(molecule, mappings, to_ff, attribute_keep=(), attribute_must=(), attribute_stash=()):
+def do_mapping(molecule, mappings, to_ff, attribute_keep=(), attribute_must=()):
     """
     Creates a new :class:`~vermouth.molecule.Molecule` in force field `to_ff`
     from `molecule`, based on `mappings`. It does this by doing a subgraph
@@ -539,11 +539,6 @@ def do_mapping(molecule, mappings, to_ff, attribute_keep=(), attribute_must=(),
         The attributes that the nodes in the output graph *must* have. If
         they're not provided by the mappings/blocks they're taken from
         `molecule`.
-    attribute_stash: tuple[str]
-        The attributes that will always be transferred from the input molecule
-        to the produced graph, but prefixed with _old_.Thus they are new attributes
-        and are not conflicting with already defined attributes.
-
 
     Returns
     -------
@@ -553,10 +548,10 @@ def do_mapping(molecule, mappings, to_ff, attribute_keep=(), attribute_must=(),
     """
     attribute_keep = tuple(attribute_keep)
     attribute_must = tuple(attribute_must)
-    attribute_stash = tuple(attribute_stash)
     # Transferring the meta maybe should be a copy, or a deep copy...
     # If it breaks we look at this line.
     graph_out = Molecule(force_field=to_ff, meta=molecule.meta)
+    graph_out.citations.update(molecule.citations)
     mappings = build_graph_mapping_collection(molecule.force_field, to_ff, mappings)
     block_matches = []
     for mapping in mappings:
@@ -640,20 +635,18 @@ def do_mapping(molecule, mappings, to_ff, attribute_keep=(), attribute_must=(),
         if out_idx in all_references:
             ref_idx = all_references[out_idx]
             new_attrs = attrs_from_node(molecule.nodes[ref_idx],
-                                        attribute_keep+attribute_must+attribute_stash)
+                                        attribute_keep+attribute_must)
             for attr, val in new_attrs.items():
                 # Attrs in attribute_keep we always transfer, those in
                 # attribute_must we transfer only if they're not already in the
                 # created node
                 if attr in attribute_keep or attr not in graph_out.nodes[out_idx]:
                     graph_out.nodes[out_idx].update(new_attrs)
-                if attr in attribute_stash:
-                    graph_out.nodes[out_idx]["_old_"+attr] = val
         else:
             attrs = defaultdict(list)
             for mol_idx in mol_idxs:
                 new_attrs = attrs_from_node(molecule.nodes[mol_idx],
-                                            attribute_keep+attribute_must+attribute_stash)
+                                            attribute_keep+attribute_must)
                 for attr, val in new_attrs.items():
                     attrs[attr].append(val)
             attrs_not_sane = []
@@ -664,12 +657,6 @@ def do_mapping(molecule, mappings, to_ff, attribute_keep=(), attribute_must=(),
                     else:
                         # No nodes hat the attribute.
                         graph_out.nodes[out_idx][attr] = None
-                if attr in attribute_stash:
-                    if vals:
-                        graph_out.nodes[out_idx]["_old_"+attr] = vals[0]
-                    else:
-                        # No nodes hat the attribute.
-                        graph_out.nodes[out_idx]["_old_"+attr] = None
 
                 if not are_all_equal(vals):
                     attrs_not_sane.append(attr)
@@ -799,23 +786,18 @@ class DoMapping(Processor):
         The attributes that the nodes in the output graph *must* have. If
         they're not provided by the mappings/blocks they're taken from
         the original molecule.
-    attribute_stash: tuple[str]
-        The attributes that will always be transferred from the input molecule
-        to the produced graph, but prefixed with _old_.Thus they are new attributes
-        and are not conflicting with already defined attributes.
 
     See Also
     --------
     :func:`do_mapping`
     """
     def __init__(self, mappings, to_ff, delete_unknown=False, attribute_keep=(),
-                 attribute_must=(), attribute_stash=()):
+                 attribute_must=()):
         self.mappings = mappings
         self.to_ff = to_ff
         self.delete_unknown = delete_unknown
         self.attribute_keep = tuple(attribute_keep)
         self.attribute_must = tuple(attribute_must)
-        self.attribute_stash = tuple(attribute_stash)
         super().__init__()
 
     def run_molecule(self, molecule):
@@ -825,7 +807,6 @@ class DoMapping(Processor):
             to_ff=self.to_ff,
             attribute_keep=self.attribute_keep,
             attribute_must=self.attribute_must,
-            attribute_stash=self.attribute_stash
         )
 
     def run_system(self, system):
