@@ -245,8 +245,7 @@ def test_peptide():
             peptide.nodes[node]['resid'] = 5
 
     # make sure the old resids with the gap are stashed
-    cg = do_mapping(peptide, mappings, FF_MARTINI, attribute_keep=('chain',),
-                    attribute_stash=('resid',))
+    cg = do_mapping(peptide, mappings, FF_MARTINI, attribute_keep=('chain',))
 
     expected = Molecule(force_field=FF_MARTINI)
     expected.add_nodes_from({1: {'atomname': 'BB',
@@ -255,7 +254,6 @@ def test_peptide():
                                  'charge': 0.0,
                                  'charge_group': 1,
                                  'resid': 1,
-                                 '_old_resid': 1,
                                  'resname': 'GLY'},
                              2: {'atomname': 'BB',
                                  'atype': 'P5',
@@ -263,7 +261,6 @@ def test_peptide():
                                  'charge': 0.0,
                                  'charge_group': 2,
                                  'resid': 2,
-                                 '_old_resid': 5,
                                  'resname': 'ILE'},
                              3: {'atomname': 'SC1',
                                  'atype': 'AC1',
@@ -271,7 +268,6 @@ def test_peptide():
                                  'charge': 0.0,
                                  'charge_group': 3,
                                  'resid': 2,
-                                 '_old_resid': 5,
                                  'resname': 'ILE'},
                              4: {'atomname': 'BB',
                                  'atype': 'P5',
@@ -279,7 +275,6 @@ def test_peptide():
                                  'charge': 0.0,
                                  'charge_group': 4,
                                  'resid': 3,
-                                 '_old_resid': 3,
                                  'resname': 'LEU'},
                              5: {'atomname': 'SC1',
                                  'atype': 'AC1',
@@ -287,7 +282,6 @@ def test_peptide():
                                  'charge': 0.0,
                                  'charge_group': 5,
                                  'resid': 3,
-                                 '_old_resid': 3,
                                  'resname': 'LEU'}}.items()
                             )
     expected.add_edges_from([(1, 2), (2, 3), (2, 4), (4, 5)])
